-- Set the target coordinates for proximity check
local targetCoords = vector3(2673.3173828125, -1128.8052978515625, 50.76222229003906)

local proximityRadius = 0.5
local animationDict = "ai_gestures@arthur@standing@speaker@lt_hand"
local animationName = "greet_happy_r_001"
local isBusy = false -- Variable to prevent triggering the animation multiple times while it's running
local animDuration = 2500 -- Set an appropriate duration for the animation
local hasLoadedDict = false -- Variable to ensure the dictionary is loaded only once

-- Function to request and load animation dictionary
function loadAnimDict(dict)
    if not HasAnimDictLoaded(dict) then
        RequestAnimDict(dict)
        while not HasAnimDictLoaded(dict) do
            Citizen.Wait(10)
        end
    end
end

-- Preload animation dictionary (optional, depending on how you want to structure it)
Citizen.CreateThread(function()
    loadAnimDict(animationDict)
    hasLoadedDict = true -- Set the flag to true once the animation is loaded
end)

-- Main thread
Citizen.CreateThread(function()
    while true do
        Citizen.Wait(0) -- Run every frame

        -- Get player position
        local playerPed = PlayerPedId()
        local playerCoords = GetEntityCoords(playerPed)

        -- Calculate the distance between player and the target coordinates
        local distance = #(playerCoords - targetCoords)

        -- Check if within proximity radius and not busy with the animation
        if distance <= proximityRadius and not isBusy and hasLoadedDict then
            -- Display a prompt to press G
            DisplayHelpText("Press G to rub Bobbys nose for luck") -- Custom function for help text

            -- If the player presses the G key (Default control for 'INPUT_CONTEXT')
            if IsControlJustReleased(0, 0x760A9C6F) then -- '0x760A9C6F' is the control for G key
                isBusy = true -- Mark as busy to prevent re-triggering the animation

                -- Ensure the dictionary is still loaded (in case it gets unloaded)
                loadAnimDict(animationDict)

                -- Clear any ongoing tasks before starting the animation
                ClearPedTasksImmediately(playerPed) -- Instantly clears tasks to ensure a clean slate

                -- Wait a short time after loading the animation to ensure everything is ready
                Citizen.Wait(200) -- Increase the wait slightly for better reliability

                -- Load and perform the animation
                TaskPlayAnim(playerPed, animationDict, animationName, 8.0, -8.0, animDuration, 49, 0, false, false, false)

                -- Use a task monitor to ensure the animation is actually playing
                local isAnimPlaying = true
                Citizen.CreateThread(function()
                    while isAnimPlaying do
                        Citizen.Wait(500)
                        if not IsEntityPlayingAnim(playerPed, animationDict, animationName, 3) then
                            isAnimPlaying = false
                        end
                    end
                end)

                -- Wait for the animation to finish or be interrupted
                Citizen.Wait(animDuration + 500) -- Slightly longer than animDuration to handle any delays

                -- Reset the busy flag to allow the animation to be triggered again
                isBusy = false
            end
        end
    end
end)

-- Function to display help text on the screen (RedM compatible)
function DisplayHelpText(text)
    SetTextScale(0.5, 0.5)
    SetTextFontForCurrentCommand(1)
    SetTextColor(255, 255, 255, 255)
    SetTextCentre(true)
    DisplayText(CreateVarString(10, "LITERAL_STRING", text), 0.5, 0.9)
end
